use std::fmt;
use std::any::Any;

use slog::Logger;
use super::auth_capnp::authentication::Client;

pub struct Authentication {
    inner: Client,
}
impl fmt::Debug for Authentication {
    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
        f.debug_struct("Authentication")
            .field("inner", &self.inner.type_id())
            .finish()
    }
}

impl Authentication {
    pub fn new(inner: Client) -> Self {
        Self { inner }
    }

    pub async fn mechanisms(&mut self) -> Vec<String> {
        let req = self.inner.mechanisms_request().send().promise;
        let res = req.await.unwrap();
        let tmp = res.get().unwrap();
        tmp.get_mechs().unwrap().iter().map(|x| x.unwrap().to_string()).collect()
    }
}
